%define mpiimpl openmpi
%define mpidir %_libexecdir/%mpiimpl

Name: spooles
Version: 2.2
Release: alt0.M50.1
Summary: SParse Object Oriented Linear Equations Solver
License: Free
Group: Sciences/Mathematics
Url: http://www.netlib.org/linalg/spooles/
Packager: Eugeny A. Rostovtsev (REAL) <real at altlinux.org>

Source: %name.%version.tar.gz
Source1: http://www.netlib.org/linalg/spooles/AllInOne.ps.gz
Source2: http://www.netlib.org/linalg/spooles/Eigen.ps.gz
Source3: http://www.netlib.org/linalg/spooles/LinSol.ps.gz
Source4: http://www.netlib.org/linalg/spooles/Ordering.ps.gz
Source5: http://www.netlib.org/linalg/spooles/PP99.ps.gz
Source6: http://www.netlib.org/linalg/spooles/ReferenceManual.ps.gz

Requires: %name-common = %version-%release

BuildPreReq: %mpiimpl-devel-static

%description
SPOOLES is a library for solving sparse real and complex linear systems of
equations, written in the C language using object oriented design. At present,
there is the following functionality:

1. Compute multiple minimum degree, generalized nested dissection and
multisection orderings of matrices with symmetric structure.

2. Factor and solve square linear systems of equations with symmetric structure,
with or without pivoting for stability. The factorization can be symmetric LDLT,
Hermitian LDLH, or nonsymmetric LDU. A direct factorization or a drop tolerance
factorization can be computed. The factors and solve can be done in serial mode,
multithreaded with Solaris or POSIX threads, or with MPI.

3. Factor and solve overdetermined full rank systems of equations using a
multifrontal QR factorization, in serial or using POSIX threads.

4. Solve square linear systems using a variety of Krylov iterative methods. The
preconditioner is a drop tolerance factorization, constructed with or without
pivoting for stability. 

%package common
Summary: Architecture independent files of SPOOLES
Group: Sciences/Mathematics
BuildArch: noarch

%description common
SPOOLES is a library for solving sparse real and complex linear systems of
equations, written in the C language using object oriented design.

This package contains architecture independent files of SPOOLES.

%package -n lib%name-devel-doc
Summary: Documentation for SPOOLES
Group: Development/Documentation
BuildArch: noarch

%description  -n lib%name-devel-doc
SPOOLES is a library for solving sparse real and complex linear systems of
equations, written in the C language using object oriented design.

This package contains development documentation for SPOOLES.

%package -n lib%name-devel
Summary: Static devepopment files of SPOOLES
Group: Development/C
Requires: %name-common = %version-%release

%description  -n lib%name-devel
SPOOLES is a library for solving sparse real and complex linear systems of
equations, written in the C language using object oriented design.

This package contains static development files of SPOOLES.

%prep
%setup

%build
%make_build MPIDIR=%mpidir lib
pushd MT
%make_build MPIDIR=%mpidir lib
popd
pushd MPI
%make_build MPIDIR=%mpidir lib
popd

sed -i -e 's/\-static//' Make.inc

%make_build MPIDIR=%mpidir ADDPARAM="-Wl,-R%mpidir/lib"
pushd MT
%make_build MPIDIR=%mpidir ADDPARAM="-Wl,-R%mpidir/lib"
popd
pushd MPI
%make_build MPIDIR=%mpidir ADDPARAM="-Wl,-R%mpidir/lib"
popd

for i in Eigen/srcMPI Eigen/srcMT Eigen/srcST IVL/drivers/ Iter/src \
	Iter/drivers LinSol/srcMPI LinSol/srcMT LinSol/srcST
do
	pushd $i
	%make_build MPIDIR=%mpidir ADDPARAM="-Wl,-R%mpidir/lib"
	popd
done

%install
install -d %buildroot%_libexecdir/%name/bin
install -d %buildroot%_libexecdir/%name/lib/eigen
install -d %buildroot%_libexecdir/%name/lib/iter
install -d %buildroot%_libexecdir/%name/lib/linsol
install -d %buildroot%_libexecdir/%name/include/eigen
install -d %buildroot%_libexecdir/%name/include/iter
install -d %buildroot%_libexecdir/%name/include/linsol
install -d %buildroot%_libexecdir/%name/include/mpi
install -d %buildroot%_docdir/%name
install -d %buildroot%_datadir/%name

mv DSTree/drivers/cutoff.dvf %buildroot%_datadir/%name/
mv Eigen/drivers/*.inp %buildroot%_datadir/%name/
mv MPI/drivers/*.pg %buildroot%_datadir/%name/
mv MPI/drivers/*.input %buildroot%_datadir/%name/
mv MT/drivers/*.input %buildroot%_datadir/%name/
mv misc/drivers/*.input %buildroot%_datadir/%name/
mv SubMtx/drivers/temp* %buildroot%_datadir/%name/
mv Matrices %buildroot%_datadir/%name/

for i in A2 BPG Chv Coords DSTree DV Drand EGraph ETree Eigen FrontMtx GPart \
	Graph I2Ohash ILUMtx IV IVL InpMtx Iter MPI MSMD MT Perm SemiImplMtx SubMtx \
	SymbFac Tree Utilities ZV misc
do
	install -d %buildroot%_libexecdir/%name/bin/$i
	rm -f $i/drivers/makefile $i/drivers/*.o $i/drivers/*.c
	install -m755 $i/drivers/* %buildroot%_libexecdir/%name/bin/$i
done

install -m644 *.a MT/src/*.a MPI/src/*.a %buildroot%_libexecdir/%name/lib
install -m644 *.h %buildroot%_libexecdir/%name/include
install -m644 Eigen/*.h %buildroot%_libexecdir/%name/include/eigen
install -m644 Iter/*.h %buildroot%_libexecdir/%name/include/iter
install -m644 LinSol/*.h %buildroot%_libexecdir/%name/include/linsol
install -m644 MPI/*.h %buildroot%_libexecdir/%name/include/mpi
install -p -m644 %SOURCE1 %SOURCE2 %SOURCE3 %SOURCE4 %SOURCE5 %SOURCE6 \
	LinSol/doc/wrappers.ps.gz documentation/PP99/ASHCRAFC.ps.gz \
	%buildroot%_docdir/%name

install -m644 $(find Eigen -name '*.a') %buildroot%_libexecdir/%name/lib/eigen
install -m644 $(find Iter -name '*.a') %buildroot%_libexecdir/%name/lib/iter
install -m644 $(find LinSol -name '*.a') \
	%buildroot%_libexecdir/%name/lib/linsol

%files
%doc %name.%version.html
%_libexecdir/%name/bin

%files common
%dir %_libexecdir/%name
%_datadir/%name

%files -n lib%name-devel-doc
%_docdir/%name

%files -n lib%name-devel
%_libexecdir/%name/include
%_libexecdir/%name/lib

%changelog
* Mon May 18 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 2.2-alt0.M50.1
- Port for Branch 5.0

* Sat May 16 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 2.2-alt1
- Initial build for Sisyphus

